@@ -16,16 +16,21 @@ def DnsCheck():
     if len(matchms) == 0:
         matchsplit = ["OK" , "NO DNS - "]
     else:
-        #print('MATCH = ' + str(matchms[0]))
-        matchsplit = re.split(r'\:',str(matchms[0]))
-        #print('MATCH split = ' + str(matchsplit[1]))
+        print('MATCH = ' + str(matchms[0]))
+        #matchsplit = re.split(r'\:',str(matchms[0]))
+        ipPattern = re.compile('\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}')
+        matchsplit = re.findall(ipPattern,str(matchms[0]))
+        print('MATCH split = ' + str(matchsplit))
 
-    return matchsplit[1].lstrip()
+    return matchsplit[0]
 
 def main():
 
     dnsip = DnsCheck()
-    #print("DNS IP is =" + dnsip)
+    print("DNS IP is =" + dnsip)
+    print("DID THIS WORK " + str(findIP))
+
+
 
 if __name__ == '__main__':
     main()
